@@ -58,7 +58,7 @@ public:
   
   static const int e_intr        = EINTR;
 
-  error_number() : m_errno(0) {}
+  error_number() = default;
   error_number(int e) : m_errno(e) {}
 
   bool                is_valid() const             { return m_errno != 0; }
@@ -80,7 +80,7 @@ public:
   bool operator == (const error_number& e) const   { return m_errno == e.m_errno; }
 
 private:
-  int                 m_errno;
+  int                 m_errno{};
 };
 
 }
