@@ -5,18 +5,16 @@
 #include <algorithm>
 #include <cstdio>
 
-#include "manager.h"
-#include "thread_main.h"
 #include "dht/dht_bucket.h"
 #include "dht/dht_router.h"
 #include "dht/dht_transaction.h"
-#include "torrent/exceptions.h"
+#include "manager.h"
 #include "torrent/connection_manager.h"
-#include "torrent/download_info.h"
+#include "torrent/exceptions.h"
 #include "torrent/object.h"
+#include "torrent/object_static_map.h"
 #include "torrent/object_stream.h"
 #include "torrent/poll.h"
-#include "torrent/object_static_map.h"
 #include "torrent/throttle.h"
 #include "torrent/net/socket_address.h"
 #include "torrent/utils/log.h"
@@ -25,6 +23,23 @@
 #define LT_LOG_THIS(log_fmt, ...)                                       \
   lt_log_print_subsystem(torrent::LOG_DHT_SERVER, "dht_server", log_fmt, __VA_ARGS__);
 
+namespace {
+// Error in DHT protocol, avoids std::string ctor from communication_error
+class dht_error : public torrent::network_error {
+public:
+  dht_error(int code, const char* message) :
+      m_message(message), m_code(code) {}
+
+  int         code() const noexcept { return m_code; }
+  const char* what() const noexcept override { return m_message; }
+
+private:
+  const char* m_message;
+  int         m_code;
+};
+
+} // namespace
+
 namespace torrent {
 
 // List of all possible keys we need/support in a DHT message.
@@ -53,21 +68,8 @@ const DhtMessage::key_list_type DhtMessage::base_type::keys = {
   { key_y,          "y*S" },
 };
 
-// Error in DHT protocol, avoids std::string ctor from communication_error
-class dht_error : public network_error {
-public:
-  dht_error(int code, const char* message) : m_message(message), m_code(code) {}
-
-  virtual int          code() const throw()   { return m_code; }
-  virtual const char*  what() const throw()   { return m_message; }
-
-private:
-  const char*  m_message;
-  int          m_code;
-};
-
-DhtServer::DhtServer(DhtRouter* router) :
-    m_router(router),
+DhtServer::DhtServer(DhtRouter* router)
+  : m_router(router),
     m_uploadThrottle(manager->upload_throttle()->throttle_list()),
     m_downloadThrottle(manager->download_throttle()->throttle_list()) {
 
@@ -85,13 +87,6 @@ DhtServer::DhtServer(DhtRouter* router) :
 DhtServer::~DhtServer() {
   stop();
 
-  for (const auto& packet : m_highQueue) {
-    delete packet;
-  }
-  for (const auto& packet : m_lowQueue) {
-    delete packet;
-  }
-
   manager->connection_manager()->dec_socket_count();
 }
 
@@ -99,12 +94,12 @@ void
 DhtServer::start(int port) {
   try {
     if (!get_fd().open_datagram() || !get_fd().set_nonblock())
-      throw resource_error("Could not allocate datagram socket.");
+      throw resource_error("could not allocate datagram socket");
 
     if (!get_fd().set_reuse_address(true))
-      throw resource_error("Could not set listening port to reuse address.");
+      throw resource_error("could not set listening port to reuse address");
 
-    auto bind_address = sa_copy(m_router->address()->c_sockaddr());
+    auto bind_address = sa_copy(m_router->address());
 
     if (bind_address->sa_family != AF_INET && bind_address->sa_family != AF_INET6)
       throw resource_error("invalid address family for DHT server");
@@ -113,10 +108,11 @@ DhtServer::start(int port) {
 
     LT_LOG_THIS("starting server : %s", sap_pretty_str(bind_address).c_str());
 
+    // Figure out how to bind to both inet and inet6.
     if (!get_fd().bind_sa(bind_address.get()))
       throw resource_error("could not bind datagram socket : " + std::string(strerror(errno)));
 
-  } catch (torrent::base_error& e) {
+  } catch (const torrent::base_error&) {
     get_fd().close();
     get_fd().clear();
     throw;
@@ -169,11 +165,12 @@ DhtServer::reset_statistics() {
 
 // Ping a node whose ID we know.
 void
-DhtServer::ping(const HashString& id, const rak::socket_address* sa) {
+DhtServer::ping(const HashString& id, const sockaddr* sa) {
   // No point pinging a node that we're already contacting otherwise.
   auto itr = m_transactions.lower_bound(DhtTransaction::key(sa, 0));
+
   if (itr == m_transactions.end() || !DhtTransaction::key_match(itr->first, sa))
-    add_transaction(new DhtTransactionPing(id, sa), packet_prio_low);
+    add_transaction(std::unique_ptr<DhtTransaction>(new DhtTransactionPing(id, sa)), packet_prio_low);
 }
 
 // Contact nodes in given bucket and ask for their nodes closest to target.
@@ -183,7 +180,7 @@ DhtServer::find_node(const DhtBucket& contacts, const HashString& target) {
 
   auto n = search->get_contact();
   while (n != search->end()) {
-    add_transaction(new DhtTransactionFindNode(n), packet_prio_low);
+    add_transaction(std::unique_ptr<DhtTransaction>(new DhtTransactionFindNode(n)), packet_prio_low);
     n = search->get_contact();
   }
 
@@ -198,7 +195,7 @@ DhtServer::announce(const DhtBucket& contacts, const HashString& infoHash, Track
   auto n        = announce->get_contact();
 
   while (n != announce->end()) {
-    add_transaction(new DhtTransactionFindNode(n), packet_prio_high);
+    add_transaction(std::unique_ptr<DhtTransaction>(new DhtTransactionFindNode(n)), packet_prio_high);
     n = announce->get_contact();
   }
 
@@ -219,7 +216,6 @@ DhtServer::cancel_announce(const HashString* info_hash, const TrackerDht* tracke
 
       if ((info_hash == nullptr || announce->target() == *info_hash) && (tracker == nullptr || announce->tracker() == tracker)) {
         drop_packet(itr->second->packet());
-        delete itr->second;
         m_transactions.erase(itr++);
         continue;
       }
@@ -238,7 +234,7 @@ DhtServer::update() {
 }
 
 void
-DhtServer::process_query(const HashString& id, const rak::socket_address* sa, const DhtMessage& msg) {
+DhtServer::process_query(const HashString& id, const sockaddr* sa, const DhtMessage& msg) {
   m_queriesReceived++;
   m_networkUp = true;
 
@@ -277,7 +273,7 @@ DhtServer::create_find_node_response(const DhtMessage& req, DhtMessage& reply) {
 }
 
 void
-DhtServer::create_get_peers_response(const DhtMessage& req, const rak::socket_address* sa, DhtMessage& reply) {
+DhtServer::create_get_peers_response(const DhtMessage& req, const sockaddr* sa, DhtMessage& reply) {
   reply[key_r_token] = m_router->make_token(sa, reply.data_end);
   reply.data_end += reply[key_r_token].as_raw_string().size();
 
@@ -305,7 +301,7 @@ DhtServer::create_get_peers_response(const DhtMessage& req, const rak::socket_ad
 }
 
 void
-DhtServer::create_announce_peer_response(const DhtMessage& req, const rak::socket_address* sa, [[maybe_unused]] DhtMessage& reply) {
+DhtServer::create_announce_peer_response(const DhtMessage& req, const sockaddr* sa, [[maybe_unused]] DhtMessage& reply) {
   raw_string info_hash = req[key_a_infoHash].as_raw_string();
 
   if (info_hash.size() < HashString::size_data)
@@ -314,12 +310,16 @@ DhtServer::create_announce_peer_response(const DhtMessage& req, const rak::socke
   if (!m_router->token_valid(req[key_a_token].as_raw_string(), sa))
     throw dht_error(dht_error_protocol, "Token invalid.");
 
+  if (!sa_is_inet(sa))
+    throw internal_error("DhtServer::create_announce_peer_response called with non-inet address.");
+
   DhtTracker* tracker = m_router->get_tracker(*HashString::cast_from(info_hash.data()), true);
-  tracker->add_peer(sa->sa_inet()->address_n(), req[key_a_port].as_value());
+
+  tracker->add_peer(reinterpret_cast<const sockaddr_in*>(sa)->sin_addr.s_addr, req[key_a_port].as_value());
 }
 
 void
-DhtServer::process_response(const HashString& id, const rak::socket_address* sa, const DhtMessage& response) {
+DhtServer::process_response(const HashString& id, const sockaddr* sa, const DhtMessage& response) {
   int  transactionId = static_cast<unsigned char>(response[key_t].as_raw_string().data()[0]);
   auto itr = m_transactions.find(DhtTransaction::key(sa, transactionId));
 
@@ -336,7 +336,8 @@ DhtServer::process_response(const HashString& id, const rak::socket_address* sa,
 
   // Make sure transaction is erased even if an exception is thrown.
   try {
-    DhtTransaction* transaction = itr->second;
+    auto& transaction = itr->second;
+
 #ifdef USE_EXTRA_DEBUG
     if (DhtTransaction::key(sa, transactionId) != transaction->key(transactionId))
       throw internal_error("DhtServer::process_response key mismatch.");
@@ -344,7 +345,7 @@ DhtServer::process_response(const HashString& id, const rak::socket_address* sa,
 
     // If we contact a node but its ID is not the one we expect, ignore the reply
     // to prevent interference from rogue nodes.
-    if ((id != transaction->id() && transaction->id() != m_router->zero_id))
+    if ((id != transaction->id() && transaction->id() != torrent::DhtRouter::zero_id))
       return;
 
     switch (transaction->type()) {
@@ -364,9 +365,8 @@ DhtServer::process_response(const HashString& id, const rak::socket_address* sa,
     // Mark node responsive only if all processing was successful, without errors.
     m_router->node_replied(id, sa);
 
-  } catch (std::exception& e) {
+  } catch (const std::exception&) {
     drop_packet(itr->second->packet());
-    delete itr->second;
     m_transactions.erase(itr);
 
     m_errorsCaught++;
@@ -374,12 +374,11 @@ DhtServer::process_response(const HashString& id, const rak::socket_address* sa,
   }
 
   drop_packet(itr->second->packet());
-  delete itr->second;
   m_transactions.erase(itr);
 }
 
 void
-DhtServer::process_error(const rak::socket_address* sa, const DhtMessage& error) {
+DhtServer::process_error(const sockaddr* sa, const DhtMessage& error) {
   int  transactionId = static_cast<unsigned char>(error[key_t].as_raw_string().data()[0]);
   auto itr = m_transactions.find(DhtTransaction::key(sa, transactionId));
 
@@ -395,7 +394,6 @@ DhtServer::process_error(const rak::socket_address* sa, const DhtMessage& error)
   // few error messages are acceptable. So we do nothing and pretend the query never happened.
 
   drop_packet(itr->second->packet());
-  delete itr->second;
   m_transactions.erase(itr);
 }
 
@@ -412,10 +410,8 @@ DhtServer::parse_find_node_reply(DhtTransactionSearch* transaction, raw_string n
             std::back_inserter(list));
 
   for (auto& node : list) {
-    if (node.id() != m_router->id()) {
-      rak::socket_address sa = node.address();
-      transaction->search()->add_contact(node.id(), &sa);
-    }
+    if (node.id() != m_router->id())
+      transaction->search()->add_contact(node.id(), sa_make_inet_n(node._addr.addr, node._addr.port).get());
   }
 
   find_node_next(transaction);
@@ -431,10 +427,10 @@ DhtServer::parse_get_peers_reply(DhtTransactionGetPeers* transaction, const DhtM
     announce->receive_peers(response[key_r_values].as_raw_list());
 
   if (response[key_r_token].is_raw_string())
-    add_transaction(new DhtTransactionAnnouncePeer(transaction->id(),
-                                                   transaction->address(),
-                                                   announce->target(),
-                                                   response[key_r_token].as_raw_string()),
+    add_transaction(std::unique_ptr<DhtTransaction>(new DhtTransactionAnnouncePeer(transaction->id(),
+                                                                                   transaction->address(),
+                                                                                   announce->target(),
+                                                                                   response[key_r_token].as_raw_string())),
                     packet_prio_low);
 
   announce->update_status();
@@ -443,12 +439,14 @@ DhtServer::parse_get_peers_reply(DhtTransactionGetPeers* transaction, const DhtM
 void
 DhtServer::find_node_next(DhtTransactionSearch* transaction) {
   int priority = packet_prio_low;
+
   if (transaction->search()->is_announce())
     priority = packet_prio_high;
 
   auto node = transaction->search()->get_contact();
+
   while (node != transaction->search()->end()) {
-    add_transaction(new DhtTransactionFindNode(node), priority);
+    add_transaction(std::unique_ptr<DhtTransaction>(new DhtTransactionFindNode(node)), priority);
     node = transaction->search()->get_contact();
   }
 
@@ -456,35 +454,36 @@ DhtServer::find_node_next(DhtTransactionSearch* transaction) {
     return;
 
   auto announce = static_cast<DhtAnnounce*>(transaction->search());
+
   if (announce->complete()) {
     // We have found the 8 closest nodes to the info hash. Retrieve peers
     // from them and announce to them.
     for (node = announce->start_announce(); node != announce->end(); ++node)
-      add_transaction(new DhtTransactionGetPeers(node), packet_prio_high);
+      add_transaction(std::unique_ptr<DhtTransaction>(new DhtTransactionGetPeers(node)), packet_prio_high);
   }
 
   announce->update_status();
 }
 
 void
-DhtServer::add_packet(DhtTransactionPacket* packet, int priority) {
+DhtServer::add_packet(std::shared_ptr<DhtTransactionPacket> packet, int priority) {
   switch (priority) {
     // High priority packets are for important queries, and quite small.
     // They're added to front of high priority queue and thus will be the
     // next packets sent.
     case packet_prio_high:
-      m_highQueue.push_front(packet);
+      m_highQueue.push_front(std::move(packet));
       break;
 
     // Low priority query packets are added to the back of the high priority
     // queue and will be sent when all high priority packets have been transmitted.
     case packet_prio_low:
-      m_highQueue.push_back(packet);
+      m_highQueue.push_back(std::move(packet));
       break;
 
     // Reply packets will be processed after all of our own packets have been send.
     case packet_prio_reply:
-      m_lowQueue.push_back(packet);
+      m_lowQueue.push_back(std::move(packet));
       break;
 
     default:
@@ -494,8 +493,10 @@ DhtServer::add_packet(DhtTransactionPacket* packet, int priority) {
 
 void
 DhtServer::drop_packet(DhtTransactionPacket* packet) {
-  m_highQueue.erase(std::remove(m_highQueue.begin(), m_highQueue.end(), packet), m_highQueue.end());
-  m_lowQueue.erase(std::remove(m_lowQueue.begin(), m_lowQueue.end(), packet), m_lowQueue.end());
+  m_highQueue.erase(std::remove_if(m_highQueue.begin(), m_highQueue.end(), [packet](auto& p) { return p.get() == packet; }),
+                    m_highQueue.end());
+  m_lowQueue.erase(std::remove_if(m_lowQueue.begin(), m_lowQueue.end(), [packet](auto& p) { return p.get() == packet; }),
+                   m_lowQueue.end());
 
   if (m_highQueue.empty() && m_lowQueue.empty()) {
     this_thread::poll()->remove_write(this);
@@ -506,7 +507,7 @@ DhtServer::drop_packet(DhtTransactionPacket* packet) {
 }
 
 void
-DhtServer::create_query(transaction_itr itr, int tID, [[maybe_unused]] const rak::socket_address* sa, int priority) {
+DhtServer::create_query(transaction_itr itr, int tID, [[maybe_unused]] const sockaddr* sa, int priority) {
   if (itr->second->id() == m_router->id())
     throw internal_error("DhtServer::create_query trying to send to itself.");
 
@@ -518,7 +519,8 @@ DhtServer::create_query(transaction_itr itr, int tID, [[maybe_unused]] const rak
   *query.data_end++ = ':';
   *query.data_end++ = tID;
 
-  DhtTransaction* transaction = itr->second;
+  auto& transaction = itr->second;
+
   query[key_q] = raw_string::from_c_str(queries[transaction->type()]);
   query[key_y] = raw_bencode::from_c_str("1:q");
   query[key_v] = raw_bencode("4:" PEER_VERSION, 6);
@@ -544,7 +546,8 @@ DhtServer::create_query(transaction_itr itr, int tID, [[maybe_unused]] const rak
       break;
   }
 
-  auto packet = new DhtTransactionPacket(transaction->address(), query, tID, transaction);
+  auto packet = std::make_shared<DhtTransactionPacket>(transaction->address(), query, tID, transaction);
+
   transaction->set_packet(packet);
   add_packet(packet, priority);
 
@@ -552,17 +555,17 @@ DhtServer::create_query(transaction_itr itr, int tID, [[maybe_unused]] const rak
 }
 
 void
-DhtServer::create_response(const DhtMessage& req, const rak::socket_address* sa, DhtMessage& reply) {
+DhtServer::create_response(const DhtMessage& req, const sockaddr* sa, DhtMessage& reply) {
   reply[key_r_id] = m_router->id_raw_string();
   reply[key_t] = req[key_t];
   reply[key_y] = raw_bencode::from_c_str("1:r");
   reply[key_v] = raw_bencode("4:" PEER_VERSION, 6);
 
-  add_packet(new DhtTransactionPacket(sa, reply), packet_prio_reply);
+  add_packet(std::make_shared<DhtTransactionPacket>(sa, reply), packet_prio_reply);
 }
 
 void
-DhtServer::create_error(const DhtMessage& req, const rak::socket_address* sa, int num, const char* msg) {
+DhtServer::create_error(const DhtMessage& req, const sockaddr* sa, int num, const char* msg) {
   DhtMessage error;
 
   if (req[key_t].is_raw_string() && req[key_t].as_raw_string().size() < 67)
@@ -573,11 +576,11 @@ DhtServer::create_error(const DhtMessage& req, const rak::socket_address* sa, in
   error[key_e_0] = num;
   error[key_e_1] = raw_string::from_c_str(msg);
 
-  add_packet(new DhtTransactionPacket(sa, error), packet_prio_reply);
+  add_packet(std::make_shared<DhtTransactionPacket>(sa, error), packet_prio_reply);
 }
 
 int
-DhtServer::add_transaction(DhtTransaction* transaction, int priority) {
+DhtServer::add_transaction(std::shared_ptr<DhtTransaction> transaction, int priority) {
   // Try random transaction ID. This is to make it less likely that we reuse
   // a transaction ID from an earlier transaction which timed out and we forgot
   // about it, so that if the node replies after the timeout it's less likely
@@ -598,10 +601,8 @@ DhtServer::add_transaction(DhtTransaction* transaction, int priority) {
     id = static_cast<uint8_t>(id + 1);
 
     // Give up after trying all possible IDs. This should never happen.
-    if (id == rnd) {
-      delete transaction;
+    if (id == rnd)
       return -1;
-    }
 
     // Transaction ID wrapped around, reset iterator.
     if (id == 0)
@@ -612,7 +613,6 @@ DhtServer::add_transaction(DhtTransaction* transaction, int priority) {
   insertItr = m_transactions.insert(insertItr, std::make_pair(transaction->key(id), transaction));
 
   create_query(insertItr, id, transaction->address(), priority);
-
   start_write();
 
   return id;
@@ -622,7 +622,7 @@ DhtServer::add_transaction(DhtTransaction* transaction, int priority) {
 // transaction (except if it was only the quick timeout).
 DhtServer::transaction_itr
 DhtServer::failed_transaction(transaction_itr itr, bool quick) {
-  DhtTransaction* transaction = itr->second;
+  auto transaction = itr->second;
 
   // If it was a known node, remember that it didn't reply, unless the transaction
   // is only stalled (had quick timeout, but not full timeout).  Also if the
@@ -630,7 +630,7 @@ DhtServer::failed_transaction(transaction_itr itr, bool quick) {
   // throttling, so don't blame the remote node for not replying.
   // Finally, if we haven't received anything whatsoever so far, assume the entire
   // network is down and so we can't blame the node either.
-  if (!quick && m_networkUp && transaction->packet() == NULL && transaction->id() != m_router->zero_id)
+  if (!quick && m_networkUp && transaction->packet() == NULL && transaction->id() != torrent::DhtRouter::zero_id)
     m_router->node_inactive(transaction->id(), transaction->address());
 
   if (transaction->type() == DhtTransaction::DHT_FIND_NODE) {
@@ -642,10 +642,9 @@ DhtServer::failed_transaction(transaction_itr itr, bool quick) {
     try {
       find_node_next(transaction->as_find_node());
 
-    } catch (std::exception& e) {
+    } catch (const std::exception&) {
       if (!quick) {
         drop_packet(transaction->packet());
-        delete itr->second;
         m_transactions.erase(itr);
       }
 
@@ -658,7 +657,6 @@ DhtServer::failed_transaction(transaction_itr itr, bool quick) {
 
   } else {
     drop_packet(transaction->packet());
-    delete itr->second;
     m_transactions.erase(itr++);
     return itr;
   }
@@ -666,10 +664,8 @@ DhtServer::failed_transaction(transaction_itr itr, bool quick) {
 
 void
 DhtServer::clear_transactions() {
-  for (auto& transaction : m_transactions) {
+  for (auto& transaction : m_transactions)
     drop_packet(transaction.second->packet());
-    delete transaction.second;
-  }
 
   m_transactions.clear();
 }
@@ -680,24 +676,28 @@ DhtServer::event_read() {
 
   while (true) {
     Object request;
-    rak::socket_address sa;
     int type = '?';
     DhtMessage message;
     const HashString* nodeId = NULL;
 
+    sockaddr_in6 sa_raw{};
+    sockaddr* sa = reinterpret_cast<sockaddr*>(&sa_raw);
+
     try {
       char buffer[2048];
-      int32_t read = read_datagram(buffer, sizeof(buffer), &sa);
+      int32_t read = read_datagram_sa(buffer, sizeof(buffer), sa, sizeof(sa_raw));
 
       if (read < 0)
         break;
 
       // We can currently only process mapped-IPv4 addresses, not real IPv6.
       // Translate them to an af_inet socket_address.
-      if (sa.family() == rak::socket_address::af_inet6)
-        sa = sa.sa_inet6()->normalize_address();
+      if (sa_is_v4mapped(sa)) {
+        auto sa_unmapped = sin_from_v4mapped_in6(&sa_raw);
+        *reinterpret_cast<sockaddr_in*>(&sa_raw) = *sa_unmapped.get();
+      }
 
-      if (sa.family() != rak::socket_address::af_inet)
+      if (sa->sa_family != AF_INET)
         continue;
 
       total += read;
@@ -706,7 +706,7 @@ DhtServer::event_read() {
       // packet at all, so we don't throw an error to prevent bounce loops.
       try {
         static_map_read_bencode(buffer, buffer + read, message);
-      } catch (bencode_error& e) {
+      } catch (const bencode_error&) {
         continue;
       }
 
@@ -740,7 +740,7 @@ DhtServer::event_read() {
       }
 
       // Sanity check the returned transaction ID.
-      if ((type == 'r' || type == 'e') && 
+      if ((type == 'r' || type == 'e') &&
           (!message[key_t].is_raw_string() || message[key_t].as_raw_string().size() != 1))
         throw dht_error(dht_error_protocol, "Invalid transaction ID type/length.");
 
@@ -750,15 +750,15 @@ DhtServer::event_read() {
 
       switch (type) {
         case 'q':
-          process_query(*nodeId, &sa, message);
+          process_query(*nodeId, sa, message);
           break;
 
         case 'r':
-          process_response(*nodeId, &sa, message);
+          process_response(*nodeId, sa, message);
           break;
 
         case 'e':
-          process_error(&sa, message);
+          process_error(sa, message);
           break;
 
         default:
@@ -768,23 +768,22 @@ DhtServer::event_read() {
     // If node was querying us, reply with error packet, otherwise mark the node as "query failed",
     // so that if it repeatedly sends malformed replies we will drop it instead of propagating it
     // to other nodes.
-    } catch (bencode_error& e) {
+    } catch (const bencode_error& e) {
       if ((type == 'r' || type == 'e') && nodeId != NULL) {
-        m_router->node_inactive(*nodeId, &sa);
+        m_router->node_inactive(*nodeId, sa);
       } else {
-        snprintf(message.data_end, message.data + message.data_size - message.data_end - 1, "Malformed packet: %s", e.what());
-        message.data[message.data_size - 1] = '\0';
-        create_error(message, &sa, dht_error_protocol, message.data_end);
+        snprintf(message.data_end, message.data + torrent::DhtMessage::data_size - message.data_end - 1, "Malformed packet: %s", e.what());
+        message.data[torrent::DhtMessage::data_size - 1] = '\0';
+        create_error(message, sa, dht_error_protocol, message.data_end);
       }
 
-    } catch (dht_error& e) {
+    } catch (const dht_error& e) {
       if ((type == 'r' || type == 'e') && nodeId != NULL)
-        m_router->node_inactive(*nodeId, &sa);
+        m_router->node_inactive(*nodeId, sa);
       else
-        create_error(message, &sa, e.code(), e.what());
-
-    } catch (network_error& e) {
+        create_error(message, sa, e.code(), e.what());
 
+    } catch (const network_error&) {
     }
   }
 
@@ -799,8 +798,9 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
   uint32_t used = 0;
 
   while (!queue.empty()) {
-    DhtTransactionPacket* packet = queue.front();
+    auto packet = queue.front();
     DhtTransaction::key_type transactionKey = 0;
+
     if(packet->has_transaction())
       transactionKey = packet->transaction()->key(packet->id());
 
@@ -808,7 +808,6 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
     // and don't bother sending non-transaction packets (replies) after
     // more than 15 seconds in the queue.
     if (packet->has_failed() || packet->age() > 15) {
-      delete packet;
       queue.pop_front();
       continue;
     }
@@ -821,7 +820,7 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
     queue.pop_front();
 
     try {
-      int written = write_datagram(packet->c_str(), packet->length(), packet->address());
+      int written = write_datagram_sa(packet->c_str(), packet->length(), packet->address());
 
       if (written == -1)
         throw network_error();
@@ -832,7 +831,7 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
       if (static_cast<unsigned int>(written) != packet->length())
         throw network_error();
 
-    } catch (network_error& e) {
+    } catch (const network_error&) {
       // Couldn't write packet, maybe something wrong with node address or routing, so mark node as bad.
       if (packet->has_transaction()) {
         auto itr = m_transactions.find(transactionKey);
@@ -846,11 +845,10 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
     if (packet->has_transaction()) {
       // here transaction can be already deleted by failed_transaction.
       auto itr = m_transactions.find(transactionKey);
+
       if (itr != m_transactions.end())
         packet->transaction()->set_packet(NULL);
     }
-
-    delete packet;
   }
 
   m_uploadThrottle->node_used(&m_uploadNode, used);
@@ -912,4 +910,4 @@ DhtServer::receive_timeout() {
   start_write();
 }
 
-}
+} // namespace torrent
