@@ -7,10 +7,14 @@
 #include "dht/dht_bucket.h"
 #include "torrent/exceptions.h"
 #include "torrent/object_stream.h"
+#include "torrent/net/socket_address.h"
 #include "tracker/tracker_dht.h"
 
 namespace torrent {
 
+template<>
+const DhtMessage::key_list_type DhtMessage::base_type::keys;
+
 DhtSearch::DhtSearch(const HashString& target, const DhtBucket& contacts)
   : base_type(dht_compare_closer(target)),
     m_next(end()),
@@ -25,19 +29,14 @@ DhtSearch::~DhtSearch() {
   // case.
   assert(!m_pending && "DhtSearch::~DhtSearch called with pending transactions.");
   assert(m_concurrency == 3 && "DhtSearch::~DhtSearch called with invalid concurrency limit.");
-
-  for (auto& [node, _] : *this)
-    delete node;
 }
 
 bool
-DhtSearch::add_contact(const HashString& id, const rak::socket_address* sa) {
-  auto n = new DhtNode(id, sa);
-  bool added = emplace(n, this).second;
+DhtSearch::add_contact(const HashString& id, const sockaddr* sa) {
+  auto n = std::make_unique<DhtNode>(id, sa);
+  bool added = emplace(std::move(n), this).second;
 
-  if (!added)
-    delete n;
-  else
+  if (added)
     m_restart = true;
 
   return added;
@@ -69,7 +68,7 @@ DhtSearch::add_contacts(const DhtBucket& contacts) {
 // Check if a node has been contacted yet.  This is the case if it is not currently
 // being contacted, nor has it been found to be good or bad.
 bool
-DhtSearch::node_uncontacted(const DhtNode* node) const {
+DhtSearch::node_uncontacted(const std::unique_ptr<DhtNode>& node) {
   return !node->is_active() && !node->is_good() && !node->is_bad();
 }
 
@@ -103,7 +102,6 @@ DhtSearch::trim(bool final) {
     // If we have all we need, delete current node unless it is
     // currently being contacted.
     if (!itr.node()->is_active() && needClosest <= 0 && (!itr.node()->is_good() || needGood <= 0)) {
-      delete itr.node();
       erase(itr++);
       continue;
     }
@@ -134,7 +132,7 @@ DhtSearch::get_contact() {
   if (ret == end())
     return ret;
 
-  set_node_active(ret, true);
+  set_node_active(ret.node(), true);
   m_pending++;
   m_contacted++;
 
@@ -148,16 +146,16 @@ DhtSearch::get_contact() {
 }
 
 void
-DhtSearch::node_status(const_accessor& n, bool success) {
-  if (n == end() || !n.node()->is_active())
+DhtSearch::node_status(const std::unique_ptr<DhtNode>& n, bool success) {
+  if (!n->is_active())
     throw internal_error("DhtSearch::node_status called for invalid/inactive node.");
 
   if (success) {
-    n.node()->set_good();
+    n->set_good();
     m_replied++;
 
   } else {
-    n.node()->set_bad();
+    n->set_bad();
   }
 
   m_pending--;
@@ -202,12 +200,31 @@ DhtAnnounce::start_announce() {
   m_replied = 0;
   m_tracker->set_dht_state(TrackerDht::state_announcing);
 
-  for (const_accessor itr(begin()); itr != end(); ++itr)
-    set_node_active(itr, true);
+  for (const auto& [node, _] : *this)
+    set_node_active(node, true);
 
   return const_accessor(begin());
 }
 
+//
+// DhtTransactionPacket:
+//
+
+DhtTransactionPacket::DhtTransactionPacket(const sockaddr* s, const DhtMessage& d, unsigned int id, std::shared_ptr<DhtTransaction> t)
+  : m_socket_address(sa_copy(s)),
+    m_id(id),
+    m_transaction(std::move(t)) {
+
+  build_buffer(d);
+}
+
+DhtTransactionPacket::DhtTransactionPacket(const sockaddr* s, const DhtMessage& d)
+  : m_socket_address(sa_copy(s)),
+    m_id(-this_thread::cached_seconds().count()) {
+
+  build_buffer(d);
+}
+
 void
 DhtTransactionPacket::build_buffer(const DhtMessage& msg) {
   char buffer[1500];  // If the message would exceed an Ethernet frame, something went very wrong.
@@ -215,13 +232,14 @@ DhtTransactionPacket::build_buffer(const DhtMessage& msg) {
 
   m_length = result.second - buffer;
   m_data   = std::make_unique<char[]>(m_length);
+
   memcpy(m_data.get(), buffer, m_length);
 }
 
-DhtTransaction::DhtTransaction(int quick_timeout, int timeout, const HashString& id, const rak::socket_address* sa)
+DhtTransaction::DhtTransaction(int quick_timeout, int timeout, const HashString& id, const sockaddr* sa)
   : m_id(id),
     m_hasQuickTimeout(quick_timeout > 0),
-    m_sa(*sa),
+    m_socket_address(sa_copy(sa)),
     m_timeout(this_thread::cached_seconds().count() + timeout),
     m_quickTimeout(this_thread::cached_seconds().count() + quick_timeout) {
 }
@@ -231,6 +249,22 @@ DhtTransaction::~DhtTransaction() {
     m_packet->set_failed();
 }
 
+DhtTransaction::key_type
+DhtTransaction::key(const sockaddr* sa, int id) {
+  if (!sa_is_inet(sa))
+    throw internal_error("DhtTransaction::key called with non-inet address.");
+
+  return (static_cast<uint64_t>(reinterpret_cast<const sockaddr_in*>(sa)->sin_addr.s_addr) << 32) + id;
+}
+
+bool
+DhtTransaction::key_match(key_type key, const sockaddr* sa) {
+  if (!sa_is_inet(sa))
+    throw internal_error("DhtTransaction::key_match called with non-inet address.");
+
+  return (key >> 32) == static_cast<uint64_t>(reinterpret_cast<const sockaddr_in*>(sa)->sin_addr.s_addr);
+}
+
 void
 DhtTransactionSearch::set_stalled() {
   if (!m_hasQuickTimeout)
@@ -251,7 +285,7 @@ DhtTransactionSearch::complete(bool success) {
   if (!m_hasQuickTimeout)
     m_search->m_concurrency--;
 
-  m_search->node_status(m_node, success);
+  m_search->node_status(m_node.node(), success);
   m_node = m_search->end();
 }
 
@@ -263,4 +297,24 @@ DhtTransactionSearch::~DhtTransactionSearch() {
     delete m_search;
 }
 
+DhtTransaction::transaction_type
+DhtTransactionPing::type() const {
+  return DHT_PING;
 }
+
+DhtTransaction::transaction_type
+DhtTransactionFindNode::type() const {
+  return DHT_FIND_NODE;
+}
+
+DhtTransaction::transaction_type
+DhtTransactionGetPeers::type() const {
+  return DHT_GET_PEERS;
+}
+
+DhtTransaction::transaction_type
+DhtTransactionAnnouncePeer::type() const {
+  return DHT_ANNOUNCE_PEER;
+}
+
+} // namespace torrent
