@@ -36,7 +36,6 @@
 
 #include "config.h"
 
-#include <stdlib.h>
 #include <algorithm>
 #include <iterator>
 
@@ -96,4 +95,4 @@ AvailableList::erase(const rak::socket_address& sa) {
   }
 }
 
-}
+} // namespace torrent
