@@ -4,29 +4,28 @@
 
 #include <cassert>
 #include <cstring>
-#include <limits>
 
-#include "manager.h"
 #include "data/chunk_list.h"
 #include "download/available_list.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
 #include "download/download_wrapper.h"
+#include "manager.h"
 #include "protocol/extensions.h"
 #include "protocol/handshake_manager.h"
 #include "protocol/initial_seed.h"
 #include "protocol/peer_connection_base.h"
 #include "protocol/peer_factory.h"
-#include "torrent/download.h"
-#include "torrent/exceptions.h"
-#include "torrent/throttle.h"
 #include "torrent/data/file_list.h"
-#include "torrent/download/download_manager.h"
+#include "torrent/download.h"
 #include "torrent/download/choke_queue.h"
-#include "torrent/download/choke_group.h"
+#include "torrent/download/download_manager.h"
+#include "torrent/download_info.h"
+#include "torrent/exceptions.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/peer/peer.h"
 #include "torrent/peer/peer_info.h"
+#include "torrent/throttle.h"
 #include "torrent/tracker/manager.h"
 #include "torrent/utils/log.h"
 #include "tracker/thread_tracker.h"
@@ -94,7 +93,7 @@ DownloadMain::~DownloadMain() {
 
 void
 DownloadMain::post_initialize() {
-  auto tracker_controller = new TrackerController(m_tracker_list);
+  auto tracker_controller = std::make_shared<TrackerController>(m_tracker_list);
 
   m_tracker_list->slot_success()          = [tracker_controller](const auto& t, auto al) { return tracker_controller->receive_success(t, al); };
   m_tracker_list->slot_failure()          = [tracker_controller](const auto& t, const auto& str) { tracker_controller->receive_failure(t, str); };
@@ -103,7 +102,7 @@ DownloadMain::post_initialize() {
   m_tracker_list->slot_tracker_disabled() = [tracker_controller](const auto& t) { tracker_controller->receive_tracker_disabled(t); };
 
   // TODO: Move tracker list to manager, and add the proper barrier for slots.
-  m_tracker_controller = thread_tracker()->tracker_manager()->add_controller(info(), tracker_controller);
+  m_tracker_controller = thread_tracker()->tracker_manager()->add_controller(info(), std::move(tracker_controller));
 }
 
 std::pair<ThrottleList*, ThrottleList*>
@@ -210,7 +209,7 @@ DownloadMain::start_initial_seeding() {
   if (!file_list()->is_done())
     return false;
 
-  m_initial_seeding.reset(new InitialSeeding(this));
+  m_initial_seeding = std::make_unique<InitialSeeding>(this);
   return true;
 }
 
@@ -246,6 +245,11 @@ DownloadMain::initial_seeding_done(PeerConnectionBase* pcb) {
   throw close_connection();
 }
 
+bool
+DownloadMain::want_pex_msg() {
+  return m_info->is_pex_active() && m_peerList.available_list()->want_more();
+}
+
 void
 DownloadMain::update_endgame() {
   if (!m_delegator.get_aggressive() &&
@@ -328,10 +332,10 @@ DownloadMain::receive_tracker_request() {
   m_tracker_controller.start_requesting();
 }
 
-bool
+static bool
 SocketAddressCompact_less(const SocketAddressCompact& a, const SocketAddressCompact& b) {
   return (a.addr < b.addr) || ((a.addr == b.addr) && (a.port < b.port));
-};
+}
 
 void
 DownloadMain::do_peer_exchange() {
@@ -409,14 +413,14 @@ DownloadMain::do_peer_exchange() {
   removed.reserve(m_ut_pex_list.size());
   std::set_difference(m_ut_pex_list.begin(), m_ut_pex_list.end(), current.begin(), current.end(), std::back_inserter(removed), SocketAddressCompact_less);
 
-  if (current.size() > m_info->max_size_pex_list()) {
+  if (current.size() > torrent::DownloadInfo::max_size_pex_list()) {
     // This test is only correct as long as we have a constant max
     // size.
-    if (added.size() < current.size() - m_info->max_size_pex_list())
+    if (added.size() < current.size() - torrent::DownloadInfo::max_size_pex_list())
       throw internal_error("DownloadMain::do_peer_exchange() added.size() < current.size() - m_info->max_size_pex_list().");
 
     // Randomize this:
-    added.erase(added.end() - (current.size() - m_info->max_size_pex_list()), added.end());
+    added.erase(added.end() - (current.size() - torrent::DownloadInfo::max_size_pex_list()), added.end());
 
     // Create the new m_ut_pex_list by removing any 'removed'
     // addresses from the original list and then adding the new
@@ -464,4 +468,4 @@ DownloadMain::set_metadata_size(size_t size) {
   m_info->set_metadata_size(size);
 }
 
-}
+} // namespace torrent
