@@ -2,27 +2,23 @@
 
 #include "manager.h"
 
-#include "thread_main.h"
 #include "data/chunk_list.h"
-#include "data/hash_queue.h"
 #include "data/hash_torrent.h"
-#include "dht/dht_router.h"
-#include "download/download_wrapper.h"
 #include "download/download_main.h"
-#include "protocol/handshake_manager.h"
+#include "download/download_wrapper.h"
 #include "net/listen.h"
+#include "protocol/handshake_manager.h"
 #include "torrent/chunk_manager.h"
 #include "torrent/connection_manager.h"
-#include "torrent/poll.h"
 #include "torrent/data/file_manager.h"
 #include "torrent/download/choke_group.h"
 #include "torrent/download/choke_queue.h"
 #include "torrent/download/download_manager.h"
 #include "torrent/download/resource_manager.h"
 #include "torrent/peer/client_list.h"
+#include "torrent/poll.h"
 #include "torrent/throttle.h"
 #include "torrent/tracker/dht_controller.h"
-#include "torrent/tracker/manager.h"
 #include "utils/instrumentation.h"
 #include "utils/thread_internal.h"
 
@@ -32,19 +28,19 @@ Manager* manager = NULL;
 
 namespace this_thread {
 
-LIBTORRENT_EXPORT void event_open(Event* event)             { utils::ThreadInternal::poll()->open(event); }
-LIBTORRENT_EXPORT void event_open_and_count(Event* event)   { utils::ThreadInternal::poll()->open(event); manager->connection_manager()->inc_socket_count(); }
-LIBTORRENT_EXPORT void event_close_and_count(Event* event)  { utils::ThreadInternal::poll()->close(event); manager->connection_manager()->dec_socket_count(); }
-LIBTORRENT_EXPORT void event_closed_and_count(Event* event) { utils::ThreadInternal::poll()->closed(event); manager->connection_manager()->dec_socket_count(); }
-LIBTORRENT_EXPORT void event_insert_read(Event* event)      { utils::ThreadInternal::poll()->insert_read(event); }
-LIBTORRENT_EXPORT void event_insert_write(Event* event)     { utils::ThreadInternal::poll()->insert_write(event); }
-LIBTORRENT_EXPORT void event_insert_error(Event* event)     { utils::ThreadInternal::poll()->insert_error(event); }
-LIBTORRENT_EXPORT void event_remove_read(Event* event)      { utils::ThreadInternal::poll()->remove_read(event); }
-LIBTORRENT_EXPORT void event_remove_write(Event* event)     { utils::ThreadInternal::poll()->remove_write(event); }
-LIBTORRENT_EXPORT void event_remove_error(Event* event)     { utils::ThreadInternal::poll()->remove_error(event); }
-LIBTORRENT_EXPORT void event_remove_and_close(Event* event) { utils::ThreadInternal::poll()->remove_and_close(event); }
+void event_open(Event* event)             { utils::ThreadInternal::poll()->open(event); }
+void event_open_and_count(Event* event)   { utils::ThreadInternal::poll()->open(event); manager->connection_manager()->inc_socket_count(); }
+void event_close_and_count(Event* event)  { utils::ThreadInternal::poll()->close(event); manager->connection_manager()->dec_socket_count(); }
+void event_closed_and_count(Event* event) { utils::ThreadInternal::poll()->cleanup_closed(event); manager->connection_manager()->dec_socket_count(); }
+void event_insert_read(Event* event)      { utils::ThreadInternal::poll()->insert_read(event); }
+void event_insert_write(Event* event)     { utils::ThreadInternal::poll()->insert_write(event); }
+void event_insert_error(Event* event)     { utils::ThreadInternal::poll()->insert_error(event); }
+void event_remove_read(Event* event)      { utils::ThreadInternal::poll()->remove_read(event); }
+void event_remove_write(Event* event)     { utils::ThreadInternal::poll()->remove_write(event); }
+void event_remove_error(Event* event)     { utils::ThreadInternal::poll()->remove_error(event); }
+void event_remove_and_close(Event* event) { utils::ThreadInternal::poll()->remove_and_close(event); }
 
-}
+} // namespace this_thread
 
 Manager::Manager()
   : m_chunk_manager(new ChunkManager),
@@ -150,4 +146,4 @@ Manager::receive_tick() {
   torrent::this_thread::scheduler()->wait_for_ceil_seconds(&m_task_tick, 30s);
 }
 
-}
+} // namespace torrent
