@@ -1,14 +1,13 @@
 #include "config.h"
 
-#include <errno.h>
+#include <cerrno>
+
 #include <fcntl.h>
-#include <sys/ioctl.h>
-#include <sys/types.h>
 #include <sys/socket.h>
-#include <arpa/inet.h>
+#include <sys/types.h>
+#include <unistd.h>
+
 #include <netinet/in.h>
-#include <netinet/in_systm.h>
-#include <netinet/ip.h>
 #include <rak/socket_address.h>
 
 #include "torrent/exceptions.h"
@@ -145,7 +144,7 @@ SocketFd::open_socket_pair(int& fd1, int& fd2) {
 }
 
 void
-SocketFd::close() {
+SocketFd::close() const {
   if (::close(m_fd) && errno == EBADF)
     throw internal_error("SocketFd::close() called on an invalid file descriptor");
 }
@@ -257,4 +256,4 @@ SocketFd::accept(rak::socket_address* sa) {
 //   return v;
 // }
 
-}
+} // namespace torrent
