@@ -1,26 +1,23 @@
 #include "config.h"
 
 #include <cstdio>
-#include <fcntl.h>
 #include <rak/error_number.h>
-#include <rak/string_manip.h>
 
 #include "data/chunk_iterator.h"
 #include "data/chunk_list.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
 #include "download/download_main.h"
-#include "net/socket_base.h"
-#include "torrent/exceptions.h"
-#include "torrent/data/block.h"
 #include "torrent/chunk_manager.h"
 #include "torrent/connection_manager.h"
-#include "torrent/download_info.h"
-#include "torrent/throttle.h"
+#include "torrent/data/block.h"
 #include "torrent/download/choke_group.h"
 #include "torrent/download/choke_queue.h"
-#include "torrent/peer/peer_info.h"
+#include "torrent/download_info.h"
+#include "torrent/exceptions.h"
 #include "torrent/peer/connection_list.h"
+#include "torrent/peer/peer_info.h"
+#include "torrent/throttle.h"
 #include "torrent/utils/log.h"
 #include "utils/instrumentation.h"
 
@@ -34,7 +31,7 @@
 
 namespace torrent {
 
-inline void
+static void
 log_mincore_stats_func(bool is_incore, bool new_index, bool& continous) {
   if (!new_index && is_incore) {
     instrumentation_update(INSTRUMENTATION_MINCORE_INCORE_TOUCHED, 1);
@@ -66,8 +63,6 @@ PeerConnectionBase::~PeerConnectionBase() {
   delete m_up;
   delete m_down;
 
-  delete m_encryptBuffer;
-
   if (m_extensions != NULL && !m_extensions->is_default())
     delete m_extensions;
 
@@ -117,11 +112,11 @@ PeerConnectionBase::initialize(DownloadMain* download, PeerInfo* peerInfo, Socke
   try {
     initialize_custom();
 
-  } catch (close_connection& e) {
+  } catch (const close_connection&) {
     // The handshake manager closes the socket for us.
-    m_peerInfo = NULL;
-    m_download = NULL;
-    m_extensions = NULL;
+    m_peerInfo   = nullptr;
+    m_download   = nullptr;
+    m_extensions = nullptr;
 
     get_fd().clear();
     return;
@@ -326,8 +321,8 @@ PeerConnectionBase::load_up_chunk() {
   if (!m_upChunk.is_valid())
     throw storage_error("File chunk read error: " + std::string(m_upChunk.error_number().c_str()));
 
-  if (is_encrypted() && m_encryptBuffer == NULL) {
-    m_encryptBuffer = new EncryptBuffer();
+  if (is_encrypted() && m_encryptBuffer == nullptr) {
+    m_encryptBuffer = std::make_unique<EncryptBuffer>();
     m_encryptBuffer->reset();
   }
 
@@ -673,7 +668,7 @@ PeerConnectionBase::down_extension() {
 
 inline uint32_t
 PeerConnectionBase::up_chunk_encrypt(uint32_t quota) {
-  if (m_encryptBuffer == NULL)
+  if (m_encryptBuffer == nullptr)
     throw internal_error("PeerConnectionBase::up_chunk: m_encryptBuffer is NULL.");
 
   if (quota <= m_encryptBuffer->remaining())
@@ -985,4 +980,4 @@ void
 PeerConnectionBase::receive_metadata_piece([[maybe_unused]] uint32_t piece, [[maybe_unused]] const char* data, [[maybe_unused]] uint32_t length) {
 }
 
-}
+} // namespace torrent
