@@ -1,13 +1,9 @@
 #include "config.h"
 
-#include <sys/types.h>
+#include "torrent/connection_manager.h"
 
-#include "manager.h"
-#include "thread_main.h"
 #include "net/listen.h"
 #include "rak/socket_address.h"
-#include "torrent/connection_manager.h"
-#include "torrent/error.h"
 #include "torrent/exceptions.h"
 #include "torrent/net/socket_address.h"
 
@@ -84,10 +80,19 @@ ConnectionManager::set_proxy_address(const sockaddr* sa) {
 
 uint32_t
 ConnectionManager::filter(const sockaddr* sa) {
-  if (!m_slot_filter)
-    return 1;
-  else
+  if (m_block_ipv4 && sa_is_inet(sa))
+    return 0;
+
+  if (m_block_ipv6 && sa_is_inet6(sa))
+    return 0;
+
+  if (m_block_ipv4in6 && sa_is_v4mapped(sa))
+    return 0;
+
+  if (m_slot_filter)
     return m_slot_filter(sa);
+
+  return 1;
 }
 
 bool
@@ -97,9 +102,9 @@ ConnectionManager::listen_open(port_type begin, port_type end) {
   if (m_bindAddress->sa_family == AF_INET || m_bindAddress->sa_family == AF_INET6)
     bind_address = sa_copy(m_bindAddress);
   else if (m_block_ipv6)
-    bind_address = sa_make_inet();
+    bind_address = sa_make_inet_any();
   else
-    bind_address = sa_make_inet6();
+    bind_address = sa_make_inet6_any();
 
   // TODO: Add blocking of ipv4 on socket level.
 
@@ -127,4 +132,4 @@ ConnectionManager::set_listen_backlog(int v) {
   m_listen_backlog = v;
 }
 
-}
+} // namespace torrent
