@@ -1,20 +1,16 @@
 #include "config.h"
 
-#include "socket_address.h"
-
 #include <algorithm>
 #include <arpa/inet.h>
 #include <cstring>
 #include <sys/un.h>
 
-// TODO: Deprecate.
-#include "rak/socket_address.h"
-
 #include "torrent/exceptions.h"
+#include "torrent/net/socket_address.h"
 
 namespace torrent {
 
-constexpr uint32_t
+static constexpr uint32_t
 sin6_addr32_index(const sockaddr_in6* sa, unsigned int index) {
   return
     (sa->sin6_addr.s6_addr[index * 4 + 0] << 24) +
@@ -23,7 +19,7 @@ sin6_addr32_index(const sockaddr_in6* sa, unsigned int index) {
     (sa->sin6_addr.s6_addr[index * 4 + 3] << 0);
 }
 
-inline void
+static void
 sin6_addr32_set(sockaddr_in6* sa, unsigned int index, uint32_t value) {
   sa->sin6_addr.s6_addr[index * 4 + 0] = (value >> 24);
   sa->sin6_addr.s6_addr[index * 4 + 1] = (value >> 16);
@@ -31,7 +27,7 @@ sin6_addr32_set(sockaddr_in6* sa, unsigned int index, uint32_t value) {
   sa->sin6_addr.s6_addr[index * 4 + 3] = (value >> 0);
 }
 
-inline in6_addr
+static in6_addr
 sin6_make_addr32(uint32_t addr0, uint32_t addr1, uint32_t addr2, uint32_t addr3) {
   uint32_t addr32[4];
   addr32[0] = htonl(addr0);
@@ -138,10 +134,9 @@ sa_length(const sockaddr* sa) {
 
 sa_unique_ptr
 sa_make_unspec() {
-  sa_unique_ptr sa(new sockaddr);
+  sa_unique_ptr sa(new sockaddr{});
 
-  std::memset(sa.get(), 0, sizeof(sockaddr));
-  sa.get()->sa_family = AF_UNSPEC;
+  sa->sa_family = AF_UNSPEC;
 
   return sa;
 }
@@ -151,19 +146,38 @@ sa_make_inet() {
   return sa_unique_ptr(reinterpret_cast<sockaddr*>(sin_make().release()));
 }
 
+sa_unique_ptr
+sa_make_inet_any() {
+  return sa_unique_ptr(reinterpret_cast<sockaddr*>(sin_make_any().release()));
+}
+
+sa_unique_ptr
+sa_make_inet_h(uint32_t addr, uint16_t port) {
+  return sa_unique_ptr(reinterpret_cast<sockaddr*>(sin_make_h(addr, port).release()));
+}
+
+sa_unique_ptr
+sa_make_inet_n(uint32_t addr, uint16_t port) {
+  return sa_unique_ptr(reinterpret_cast<sockaddr*>(sin_make_n(addr, port).release()));
+}
+
 sa_unique_ptr
 sa_make_inet6() {
   return sa_unique_ptr(reinterpret_cast<sockaddr*>(sin6_make().release()));
 }
 
+sa_unique_ptr
+sa_make_inet6_any() {
+  return sa_unique_ptr(reinterpret_cast<sockaddr*>(sin6_make_any().release()));
+}
+
 sa_unique_ptr
 sa_make_unix(const std::string& pathname) {
   if (!pathname.empty())
     throw internal_error("torrent::sa_make_unix: function not implemented");
 
-  sun_unique_ptr sunp(new sockaddr_un);
+  sun_unique_ptr sunp(new sockaddr_un{});
 
-  std::memset(sunp.get(), 0, sizeof(sockaddr_un));
   sunp->sun_family = AF_UNIX;
   // TODO: verify length, copy pathname
 
@@ -240,8 +254,7 @@ sa_copy_addr(const sockaddr* sa, uint16_t port) {
 
 sa_unique_ptr
 sa_copy_addr_in(const sockaddr_in* sa, uint16_t port) {
-  sa_unique_ptr result(reinterpret_cast<sockaddr*>(new sockaddr_in));
-  std::memset(result.get(), 0, sizeof(sockaddr_in));
+  sa_unique_ptr result(reinterpret_cast<sockaddr*>(new sockaddr_in{}));
   reinterpret_cast<sockaddr_in*>(result.get())->sin_family = AF_INET;
   reinterpret_cast<sockaddr_in*>(result.get())->sin_addr = sa->sin_addr;
   reinterpret_cast<sockaddr_in*>(result.get())->sin_port = htons(port);
@@ -250,8 +263,7 @@ sa_copy_addr_in(const sockaddr_in* sa, uint16_t port) {
 
 sa_unique_ptr
 sa_copy_addr_in6(const sockaddr_in6* sa, uint16_t port) {
-  sa_unique_ptr result(reinterpret_cast<sockaddr*>(new sockaddr_in6));
-  std::memset(result.get(), 0, sizeof(sockaddr_in6));
+  sa_unique_ptr result(reinterpret_cast<sockaddr*>(new sockaddr_in6{}));
   reinterpret_cast<sockaddr_in6*>(result.get())->sin6_family = AF_INET6;
   std::memcpy(&reinterpret_cast<sockaddr_in6*>(result.get())->sin6_addr, &sa->sin6_addr, sizeof(in6_addr));
   reinterpret_cast<sockaddr_in6*>(result.get())->sin6_port = htons(port);
@@ -297,18 +309,60 @@ sa_free(const sockaddr* sa) {
 
 sin_unique_ptr
 sin_make() {
-  sin_unique_ptr sa(new sockaddr_in);
-  std::memset(sa.get(), 0, sizeof(sockaddr_in));
-  sa.get()->sin_family = AF_INET;
+  sin_unique_ptr sa(new sockaddr_in{});
+
+  sa->sin_family = AF_INET;
+
+  return sa;
+}
+
+sin_unique_ptr
+sin_make_any() {
+  sin_unique_ptr sa(new sockaddr_in{});
+
+  sa->sin_family = AF_INET;
+  sa->sin_addr.s_addr = htonl(INADDR_ANY);
+
+  return sa;
+}
+
+sin_unique_ptr
+sin_make_h(uint32_t addr, uint16_t port) {
+  sin_unique_ptr sa(new sockaddr_in{});
+
+  sa->sin_family = AF_INET;
+  sa->sin_addr.s_addr = htonl(addr);
+  sa->sin_port = htons(port);
+
+  return sa;
+}
+
+sin_unique_ptr
+sin_make_n(uint32_t addr, uint16_t port) {
+  sin_unique_ptr sa(new sockaddr_in{});
+
+  sa->sin_family = AF_INET;
+  sa->sin_addr.s_addr = addr;
+  sa->sin_port = port;
 
   return sa;
 }
 
 sin6_unique_ptr
 sin6_make() {
-  sin6_unique_ptr sa(new sockaddr_in6);
-  std::memset(sa.get(), 0, sizeof(sockaddr_in6));
-  sa.get()->sin6_family = AF_INET6;
+  sin6_unique_ptr sa(new sockaddr_in6{});
+
+  sa->sin6_family = AF_INET6;
+
+  return sa;
+}
+
+sin6_unique_ptr
+sin6_make_any() {
+  sin6_unique_ptr sa(new sockaddr_in6{});
+
+  sa->sin6_family = AF_INET6;
+  sa->sin6_addr = in6addr_any;
 
   return sa;
 }
@@ -335,8 +389,8 @@ sin_from_v4mapped_in6(const sockaddr_in6* sin6) {
     throw internal_error("torrent::sin6_is_v4mapped: sockaddr_in6 is not v4mapped");
 
   sin_unique_ptr result = sin_make();
-  result.get()->sin_addr.s_addr = reinterpret_cast<in_addr_t>(htonl(sin6_addr32_index(sin6, 3)));
-  result.get()->sin_port = sin6->sin6_port;
+  result->sin_addr.s_addr = reinterpret_cast<in_addr_t>(htonl(sin6_addr32_index(sin6, 3)));
+  result->sin_port = sin6->sin6_port;
 
   return result;
 }
@@ -345,14 +399,14 @@ sin6_unique_ptr
 sin6_to_v4mapped_in(const sockaddr_in* sin) {
   sin6_unique_ptr result = sin6_make();
 
-  result.get()->sin6_addr = sin6_make_addr32(0, 0, 0xffff, ntohl(sin->sin_addr.s_addr));
-  result.get()->sin6_port = sin->sin_port;
+  result->sin6_addr = sin6_make_addr32(0, 0, 0xffff, ntohl(sin->sin_addr.s_addr));
+  result->sin6_port = sin->sin_port;
 
   return result;
 }
 
 sin_unique_ptr
-sin_from_sa(sa_unique_ptr&& sap) {
+sin_from_sa(sa_unique_ptr sap) {
   if (!sap_is_inet(sap))
     throw internal_error("torrent::sin_from_sa: sockaddr is nullptr or not inet");
 
@@ -360,7 +414,7 @@ sin_from_sa(sa_unique_ptr&& sap) {
 }
 
 sin6_unique_ptr
-sin6_from_sa(sa_unique_ptr&& sap) {
+sin6_from_sa(sa_unique_ptr sap) {
   if (!sap_is_inet6(sap))
     throw internal_error("torrent::sin6_from_sa: sockaddr is nullptr or not inet6");
 
@@ -368,7 +422,7 @@ sin6_from_sa(sa_unique_ptr&& sap) {
 }
 
 c_sin_unique_ptr
-sin_from_c_sa(c_sa_unique_ptr&& sap) {
+sin_from_c_sa(c_sa_unique_ptr sap) {
   if (!sap_is_inet(sap))
     throw internal_error("torrent::sin_from_c_sa: sockaddr is nullptr or not inet");
 
@@ -376,7 +430,7 @@ sin_from_c_sa(c_sa_unique_ptr&& sap) {
 }
 
 c_sin6_unique_ptr
-sin6_from_c_sa(sa_unique_ptr&& sap) {
+sin6_from_c_sa(c_sa_unique_ptr sap) {
   if (!sap_is_inet6(sap))
     throw internal_error("torrent::sin6_from_c_sa: sockaddr is nullptr or not inet6");
 
@@ -385,7 +439,7 @@ sin6_from_c_sa(sa_unique_ptr&& sap) {
 
 void
 sa_clear_inet6(sockaddr_in6* sa) {
-  std::memset(sa, 0, sizeof(sockaddr_in6));
+  *sa = sockaddr_in6{};
   sa->sin6_family = AF_INET6;
 }
 
@@ -584,4 +638,4 @@ sa_pretty_address_str(const sockaddr* sa) {
   return sa_pretty_str(sa);
 }
 
-}
+} // namespace torrent
