@@ -49,7 +49,7 @@ find_key_match(const static_map_mapping_type* first, const static_map_mapping_ty
   const static_map_mapping_type* itr = first;
 
   while (itr != last) {
-    unsigned int base = rak::count_base(key_first, key_last, itr->key, itr->key + itr->max_key_size);
+    unsigned int base = rak::count_base(key_first, key_last, itr->key, itr->key + torrent::static_map_mapping_type::max_key_size);
 
     if (key_first[base] != '\0') {
       // Return not found here if we know the entry won't come after
@@ -69,4 +69,4 @@ find_key_match(const static_map_mapping_type* first, const static_map_mapping_ty
   return static_map_key_search_result(first, 0);
 }
 
-}
+} // namespace torrent
