@@ -24,11 +24,6 @@
 
 namespace torrent {
 
-const int ConnectionList::disconnect_available;
-const int ConnectionList::disconnect_quick;
-const int ConnectionList::disconnect_unwanted;
-const int ConnectionList::disconnect_delayed;
-
 ConnectionList::ConnectionList(DownloadMain* download) :
     m_download(download) {
 }
@@ -222,4 +217,4 @@ ConnectionList::set_max_size(size_type v) {
   //m_download->choke_group()->up_queue()->balance();
 }
 
-}
+} // namespace torrent
