@@ -2,34 +2,35 @@
 
 #include "torrent/torrent.h"
 
-#include "manager.h"
-#include "thread_main.h"
+#include <curl/curl.h>
+
 #include "data/file_manager.h"
 #include "data/hash_queue.h"
-#include "data/hash_torrent.h"
 #include "data/thread_disk.h"
 #include "download/download_constructor.h"
 #include "download/download_manager.h"
 #include "download/download_wrapper.h"
+#include "manager.h"
 #include "net/thread_net.h"
 #include "protocol/handshake_manager.h"
 #include "protocol/peer_factory.h"
-#include "rak/address_info.h"
 #include "rak/string_manip.h"
+#include "thread_main.h"
 #include "torrent/connection_manager.h"
+#include "torrent/download/resource_manager.h"
+#include "torrent/download_info.h"
 #include "torrent/exceptions.h"
 #include "torrent/object.h"
 #include "torrent/object_stream.h"
-#include "torrent/throttle.h"
-#include "torrent/poll.h"
 #include "torrent/peer/connection_list.h"
-#include "torrent/download/resource_manager.h"
+#include "torrent/poll.h"
+#include "torrent/throttle.h"
 #include "tracker/thread_tracker.h"
 #include "utils/instrumentation.h"
 
 namespace torrent {
 
-uint32_t
+static uint32_t
 calculate_max_open_files(uint32_t openMax) {
   if (openMax >= 8096)
     return 256;
@@ -43,7 +44,7 @@ calculate_max_open_files(uint32_t openMax) {
     return 4;
 }
 
-uint32_t
+static uint32_t
 calculate_reserved(uint32_t openMax) {
   if (openMax >= 8096)
     return 256;
@@ -60,7 +61,7 @@ calculate_reserved(uint32_t openMax) {
 void
 initialize_main_thread() {
   ThreadMain::create_thread();
-  thread_main()->init_thread();
+  ThreadMain::thread_main()->init_thread();
 }
 
 void
@@ -69,12 +70,13 @@ initialize() {
     throw internal_error("torrent::initialize(...) called but the library has already been initialized");
 
   instrumentation_initialize();
+  curl_global_init(CURL_GLOBAL_ALL);
 
   manager = new Manager;
 
   ThreadDisk::create_thread();
   ThreadNet::create_thread();
-  ThreadTracker::create_thread(thread_main());
+  ThreadTracker::create_thread(ThreadMain::thread_main());
 
   uint32_t maxFiles = calculate_max_open_files(this_thread::poll()->open_max());
 
@@ -82,11 +84,11 @@ initialize() {
   manager->file_manager()->set_max_open_files(maxFiles);
 
   thread_disk()->init_thread();
-  thread_net()->init_thread();
+  net_thread::thread()->init_thread();
   thread_tracker()->init_thread();
 
   thread_disk()->start_thread();
-  thread_net()->start_thread();
+  net_thread::thread()->start_thread();
   thread_tracker()->start_thread();
 }
 
@@ -102,14 +104,16 @@ cleanup() {
 
   thread_tracker()->stop_thread_wait();
   thread_disk()->stop_thread_wait();
-  thread_net()->stop_thread_wait();
+  net_thread::thread()->stop_thread_wait();
 
   delete thread_tracker();
   delete thread_disk();
-  delete thread_net();
+  delete net_thread::thread();
 
   delete manager;
   manager = NULL;
+
+  curl_global_cleanup();
 }
 
 bool
@@ -124,7 +128,7 @@ is_inactive() {
 
 void
 set_main_thread_slots(std::function<void()> do_work) {
-  thread_main()->slot_do_work() = std::move(do_work);
+  ThreadMain::thread_main()->slot_do_work() = std::move(do_work);
 }
 
 ChunkManager*      chunk_manager() { return manager->chunk_manager(); }
@@ -180,7 +184,7 @@ download_add(Object* object, uint32_t tracker_key) {
 
   std::string local_id = PEER_NAME + rak::generate_random<std::string>(20 - std::string(PEER_NAME).size());
 
-  download->set_hash_queue(thread_main()->hash_queue());
+  download->set_hash_queue(ThreadMain::thread_main()->hash_queue());
   download->initialize(infoHash, local_id, tracker_key);
 
   // Add trackers, etc, after setting the info hash so that log
@@ -237,7 +241,7 @@ download_set_priority(Download d, uint32_t pri) {
   if (pri > 1024)
     throw internal_error("torrent::download_set_priority(...) received an invalid priority.");
 
-  manager->resource_manager()->set_priority(itr, pri);
+  ResourceManager::set_priority(itr, pri);
 }
 
-}
+} // namespace torrent
