@@ -257,7 +257,7 @@ resume_load_bitfield(Download download, const Object& object) {
 
     LT_LOG_LOAD("restoring partial bitfield", 0);
 
-    download.set_bitfield((uint8_t*)(bitfield.c_str()), (uint8_t*)((bitfield.c_str() + bitfield.size())));
+    download.set_bitfield(reinterpret_cast<const uint8_t*>(bitfield.c_str()), (reinterpret_cast<const uint8_t*>(bitfield.c_str()) + bitfield.size()));
 
   } else if (object.has_key_value("bitfield")) {
     Object::value_type chunksDone = object.get_key_value("bitfield");
@@ -540,7 +540,7 @@ resume_save_tracker_settings(Download download, Object& object) {
   auto& dest         = object.insert_preserve_copy("trackers", Object::create_map()).first->second;
   auto  tracker_list = download.main()->tracker_list();
 
-  for (auto tracker : *tracker_list) {
+  for (const auto& tracker : *tracker_list) {
     Object& trackerObject = dest.insert_key(tracker.url(), Object::create_map());
 
     trackerObject.insert_key("enabled", Object(static_cast<int64_t>(tracker.is_enabled())));
@@ -552,4 +552,4 @@ resume_save_tracker_settings(Download download, Object& object) {
   }
 }
 
-}
+} // namespace torrent
