@@ -1,25 +1,21 @@
 #include "config.h"
 
-#define __STDC_FORMAT_MACROS
-
 #include "tracker/tracker_http.h"
 
 #include <iomanip>
 #include <sstream>
 #include <utility>
-#include <rak/string_manip.h>
 
 #include "net/address_list.h"
+#include "rak/string_manip.h"
 #include "torrent/connection_manager.h"
-#include "torrent/download_info.h"
 #include "torrent/exceptions.h"
-#include "torrent/http.h"
-#include "torrent/net/utils.h"
+#include "torrent/net/http_stack.h"
 #include "torrent/net/socket_address.h"
+#include "torrent/net/utils.h"
 #include "torrent/object_stream.h"
 #include "torrent/utils/log.h"
 #include "torrent/utils/option_strings.h"
-#include "torrent/utils/thread.h"
 #include "torrent/utils/uri_parser.h"
 
 #include "manager.h"
@@ -33,19 +29,23 @@
 
 namespace torrent {
 
-TrackerHttp::TrackerHttp(const TrackerInfo& info, int flags) :
-  TrackerWorker(info, utils::uri_can_scrape(info.url) ? (flags | tracker::TrackerState::flag_scrapable) : flags),
+TrackerHttp::TrackerHttp(const TrackerInfo& info, int flags)
+  : TrackerWorker(info, utils::uri_can_scrape(info.url) ? (flags | tracker::TrackerState::flag_scrapable) : flags),
+    m_drop_deliminator(utils::uri_has_query(info.url)) {
 
-  // TODO: Change slot_factory to use thread_self poll.
-  m_get(Http::slot_factory()()),
-  m_drop_deliminator(utils::uri_has_query(info.url)) {
+  m_get.reset(info.url, nullptr);
 
-  m_get->signal_done().emplace_back([this] { receive_done(); });
-  m_get->signal_failed().emplace_back([this](const auto& str) { receive_signal_failed(str); });
+  m_get.add_done_slot([this] { receive_done(); });
+  m_get.add_failed_slot([this](const auto& str) { receive_signal_failed(str); });
 
   m_delay_scrape.slot() = [this] { delayed_send_scrape(); };
 }
 
+TrackerHttp::~TrackerHttp() {
+  close_directly();
+  this_thread::scheduler()->erase(&m_delay_scrape);
+}
+
 bool
 TrackerHttp::is_busy() const {
   return m_data != nullptr;
@@ -91,6 +91,10 @@ TrackerHttp::send_event(tracker::TrackerState::event_enum new_state) {
   if (!tracker_id.empty())
     s << "&trackerid=" << rak::copy_escape_html(tracker_id);
 
+  //
+  // TODO: Make all connection_manager related calls thread-safe.
+  //
+
   const rak::socket_address* localAddress = rak::socket_address::cast_from(manager->connection_manager()->local_address());
 
   if (localAddress->is_address_any()) {
@@ -135,16 +139,32 @@ TrackerHttp::send_event(tracker::TrackerState::event_enum new_state) {
 
   std::string request_url = s.str();
 
+  m_get.try_wait_for_close();
+  m_get.reset(request_url, m_data);
+
+  bool is_block_ipv4 = manager->connection_manager()->is_block_ipv4();
+  bool is_block_ipv6 = manager->connection_manager()->is_block_ipv6();
+  bool is_prefer_ipv6 = manager->connection_manager()->is_prefer_ipv6();
+
+  // If both IPv4 and IPv6 are blocked, we cannot send the request.
+  //
+  // TODO: Properly handle this case without throwing an error.
+
+  if (is_block_ipv4 && is_block_ipv6)
+    throw torrent::internal_error("Cannot send tracker event, both IPv4 and IPv6 are blocked.");
+  else if (is_block_ipv4)
+    m_get.use_ipv6();
+  else if (is_block_ipv6)
+    m_get.use_ipv4();
+  else if (is_prefer_ipv6)
+    m_get.prefer_ipv6();
+
   LT_LOG_DUMP(request_url.c_str(), request_url.size(),
               "sending event : state:%s up_adj:%" PRIu64 " completed_adj:%" PRIu64 " left_adj:%" PRIu64,
               option_as_string(OPTION_TRACKER_EVENT, new_state),
               parameters.uploaded_adjusted, parameters.completed_adjusted, parameters.download_left);
 
-  m_get->set_url(request_url);
-  m_get->set_stream(m_data.get());
-  m_get->set_timeout(2 * 60);
-
-  m_get->start();
+  torrent::net_thread::http_stack()->start_get(m_get);
 }
 
 void
@@ -162,7 +182,6 @@ TrackerHttp::send_scrape() {
   }
 
   LT_LOG("scrape requested : url:%s", info().url.c_str());
-
   this_thread::scheduler()->wait_for_ceil_seconds(&m_delay_scrape, 10s);
 }
 
@@ -184,17 +203,15 @@ TrackerHttp::delayed_send_scrape() {
 
   request_prefix(&s, utils::uri_generate_scrape_url(info().url));
 
-  m_data = std::make_unique<std::stringstream>();
-
   std::string request_url = s.str();
 
+  m_data = std::make_unique<std::stringstream>();
+
+  m_get.try_wait_for_close();
+  m_get.reset(request_url, m_data);
+
   LT_LOG_DUMP(request_url.c_str(), request_url.size(), "tracker scrape", 0);
-
-  m_get->set_url(request_url);
-  m_get->set_stream(m_data.get());
-  m_get->set_timeout(2 * 60);
-
-  m_get->start();
+  torrent::net_thread::http_stack()->start_get(m_get);
 }
 
 void
@@ -208,36 +225,6 @@ TrackerHttp::close() {
   close_directly();
 }
 
-// TODO: Remove 'disown' mechanic when we rewrite http request handling.
-
-void
-TrackerHttp::disown() {
-  this_thread::scheduler()->erase(&m_delay_scrape);
-  m_requested_scrape = false;
-
-  if (m_data == nullptr) {
-    LT_LOG("disowning tracker (already closed) : state:%s url:%s",
-           option_as_string(OPTION_TRACKER_EVENT, state().latest_event()), info().url.c_str());
-
-    m_slot_close();
-    return;
-  }
-
-  LT_LOG("disowning tracker : state:%s url:%s",
-         option_as_string(OPTION_TRACKER_EVENT, state().latest_event()), info().url.c_str());
-
-  m_slot_close();
-
-  m_get->set_delete_self();
-  m_get->set_delete_stream();
-  m_get->signal_done().clear();
-  m_get->signal_failed().clear();
-
-  // Allocate this dynamically, so that we don't need to do this here.
-  m_get = std::unique_ptr<Http>(Http::slot_factory()());
-  m_data.reset();
-}
-
 tracker_enum
 TrackerHttp::type() const {
   return TRACKER_HTTP;
@@ -256,12 +243,8 @@ TrackerHttp::close_directly() {
   LT_LOG("closing directly : state:%s url:%s",
          option_as_string(OPTION_TRACKER_EVENT, state().latest_event()), info().url.c_str());
 
-  // TODO: Replace m_slot_close with a ThreadWorker method.
   m_slot_close();
-
-  m_get->close();
-  m_get->set_stream(nullptr);
-
+  m_get.close_and_cancel_callbacks(this_thread::thread());
   m_data.reset();
 }
 
@@ -272,7 +255,7 @@ TrackerHttp::receive_done() {
 
   LT_LOG("received reply", 0);
 
-  if (lt_log_is_valid(LOG_TRACKER_DEBUG)) {
+  if (lt_log_is_valid(LOG_TRACKER_DUMP)) {
     std::string dump = m_data->str();
     LT_LOG_DUMP(dump.c_str(), dump.size(), "tracker reply", 0);
   }
@@ -332,7 +315,7 @@ TrackerHttp::receive_failed(const std::string& msg) {
 
   LT_LOG("received failure : msg:%s", msg.c_str());
 
-  if (lt_log_is_valid(LOG_TRACKER_DEBUG)) {
+  if (lt_log_is_valid(LOG_TRACKER_DUMP)) {
     std::string dump = m_data->str();
     LT_LOG_DUMP(dump.c_str(), dump.size(), "received failure", 0);
   }
@@ -417,7 +400,7 @@ TrackerHttp::process_success(const Object& object) {
       else if (object.get_key("peers").is_list())
         l.parse_address_normal(object.get_key_list("peers"));
 
-    } catch (bencode_error& e) {
+    } catch (const bencode_error& e) {
       return receive_failed(e.what());
     }
   }
@@ -473,4 +456,4 @@ TrackerHttp::update_tracker_id(const std::string& id) {
   set_tracker_id(id);
 }
 
-}
+} // namespace torrent
