@@ -6,6 +6,7 @@
 
 #include "torrent/object.h"
 #include "tracker/tracker_worker.h"
+#include "torrent/net/http_get.h"
 #include "torrent/tracker/tracker_state.h"
 #include "torrent/utils/scheduler.h"
 
@@ -18,13 +19,13 @@ public:
   static constexpr uint32_t http_timeout = 60;
 
   TrackerHttp(const TrackerInfo& info, int flags = 0);
+  ~TrackerHttp() override;
 
   bool                is_busy() const override;
 
   void                send_event(tracker::TrackerState::event_enum new_state) override;
   void                send_scrape() override;
   void                close() override;
-  void                disown() override;
 
   tracker_enum        type() const override;
 
@@ -45,8 +46,8 @@ private:
 
   void                update_tracker_id(const std::string& id);
 
-  std::unique_ptr<Http>              m_get;
-  std::unique_ptr<std::stringstream> m_data;
+  net::HttpGet                       m_get;
+  std::shared_ptr<std::stringstream> m_data;
 
   bool                  m_drop_deliminator;
   std::string           m_current_tracker_id;
@@ -55,6 +56,6 @@ private:
   utils::SchedulerEntry m_delay_scrape;
 };
 
-}
+} // namespace torrent
 
 #endif
