@@ -16,9 +16,6 @@ class ObjectStreamTest : public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE_END();
 
 public:
-  void setUp() {}
-  void tearDown() {}
-
   void testInputOrdered();
   void testInputNullKey();
   void testOutputMask();
